import 'package:flutter/material.dart';
import 'interest.dart';
import 'minmax.dart';
import 'orderfood.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      title: 'Drawer App',
      theme: ThemeData(
        colorScheme: ColorScheme.fromSeed(seedColor: Colors.blue),
        useMaterial3: true,
      ),
      // Define the routes
      initialRoute: '/',
      routes: {
        '/': (context) => const HomePage(),
        '/interest': (context) => const InterestCalculator(),
        '/minmax': (context) => const MinMaxScreen(),
        '/orderfood': (context) => const OrderFoodScreen(),
      },
    );
  }
}

class HomePage extends StatelessWidget {
  const HomePage({super.key});

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('My App'),
      ),
      drawer: Drawer(
        child: ListView(
          padding: EdgeInsets.zero,
          children: [
            UserAccountsDrawerHeader(
              accountName: const Text('Student'),
              accountEmail: const Text('ID: 24MCA156'), 
              currentAccountPicture: const CircleAvatar(
                backgroundImage: AssetImage('1.png'),
              ),
              decoration: BoxDecoration(
                color: Theme.of(context).colorScheme.primary,
              ),
            ),
            ListTile(
              leading: const Icon(Icons.calculate),
              title: const Text('Interest Calculator'),
              onTap: () {
                Navigator.pop(context); // Close the drawer
                Navigator.pushNamed(context, '/interest'); // Navigate using named route
              },
            ),
            ListTile(
              leading: const Icon(Icons.compare_arrows),
              title: const Text('MinMax'),
              onTap: () {
                Navigator.pop(context);
                Navigator.pushNamed(context, '/minmax');
              },
            ),
            ListTile(
              leading: const Icon(Icons.fastfood),
              title: const Text('Order Food'),
              onTap: () {
                Navigator.pop(context);
                Navigator.pushNamed(context, '/orderfood');
              },
            ),
            const Divider(),
            ListTile(
              leading: const Icon(Icons.exit_to_app),
              title: const Text('Exit'),
              onTap: () {
                Navigator.pop(context);
              },
            ),
          ],
        ),
      ),
      body: const Center(
        child: Text('Select an option from the drawer menu'),
      ),
    );
  }
}