import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class MinMaxScreen extends StatefulWidget {
  const MinMaxScreen({super.key});

  @override
  State<MinMaxScreen> createState() => _MinMaxScreenState();
}

class _MinMaxScreenState extends State<MinMaxScreen> {
  final _formKey = GlobalKey<FormState>();
  final _num1Controller = TextEditingController();
  final _num2Controller = TextEditingController();
  final _num3Controller = TextEditingController();
  
  String _result = '';
  bool _isShowingMax = false;
  bool _isShowingMin = false;

  void _calculateMax() {
    if (_formKey.currentState!.validate()) {
      setState(() {
        double num1 = double.parse(_num1Controller.text);
        double num2 = double.parse(_num2Controller.text);
        double num3 = double.parse(_num3Controller.text);
        
        double max = num1;
        if (num2 > max) max = num2;
        if (num3 > max) max = num3;
        
        _result = 'Maximum: ${max.toString()}';
        _isShowingMax = true;
        _isShowingMin = false;
      });
    }
  }

  void _calculateMin() {
    if (_formKey.currentState!.validate()) {
      setState(() {
        double num1 = double.parse(_num1Controller.text);
        double num2 = double.parse(_num2Controller.text);
        double num3 = double.parse(_num3Controller.text);
        
        double min = num1;
        if (num2 < min) min = num2;
        if (num3 < min) min = num3;
        
        _result = 'Minimum: ${min.toString()}';
        _isShowingMin = true;
        _isShowingMax = false;
      });
    }
  }

  @override
  void dispose() {
    _num1Controller.dispose();
    _num2Controller.dispose();
    _num3Controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('MinMax Calculator'),
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Form(
          key: _formKey,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              TextFormField(
                controller: _num1Controller,
                decoration: const InputDecoration(
                  labelText: 'First Number',
                  border: OutlineInputBorder(),
                  prefixIcon: Icon(Icons.filter_1),
                ),
                keyboardType: const TextInputType.numberWithOptions(decimal: true, signed: true),
                inputFormatters: [
                  FilteringTextInputFormatter.allow(RegExp(r'^-?\d*\.?\d*')),
                ],
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'Please enter a number';
                  }
                  return null;
                },
              ),
              const SizedBox(height: 16),
              TextFormField(
                controller: _num2Controller,
                decoration: const InputDecoration(
                  labelText: 'Second Number',
                  border: OutlineInputBorder(),
                  prefixIcon: Icon(Icons.filter_2),
                ),
                keyboardType: const TextInputType.numberWithOptions(decimal: true, signed: true),
                inputFormatters: [
                  FilteringTextInputFormatter.allow(RegExp(r'^-?\d*\.?\d*')),
                ],
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'Please enter a number';
                  }
                  return null;
                },
              ),
              const SizedBox(height: 16),
              TextFormField(
                controller: _num3Controller,
                decoration: const InputDecoration(
                  labelText: 'Third Number',
                  border: OutlineInputBorder(),
                  prefixIcon: Icon(Icons.filter_3),
                ),
                keyboardType: const TextInputType.numberWithOptions(decimal: true, signed: true),
                inputFormatters: [
                  FilteringTextInputFormatter.allow(RegExp(r'^-?\d*\.?\d*')),
                ],
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'Please enter a number';
                  }
                  return null;
                },
              ),
              const SizedBox(height: 24),
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  ElevatedButton(
                    onPressed: _calculateMax,
                    style: ElevatedButton.styleFrom(
                      padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
                    ),
                    child: const Text(
                      'Show Max',
                      style: TextStyle(fontSize: 16),
                    ),
                  ),
                  ElevatedButton(
                    onPressed: _calculateMin,
                    style: ElevatedButton.styleFrom(
                      padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
                    ),
                    child: const Text(
                      'Show Min',
                      style: TextStyle(fontSize: 16),
                    ),
                  ),
                ],
              ),
              const SizedBox(height: 32),
              if (_isShowingMax || _isShowingMin)
                Container(
                  padding: const EdgeInsets.all(16),
                  decoration: BoxDecoration(
                    color: _isShowingMax 
                        ? Colors.blue.shade100 
                        : Colors.green.shade100,
                    borderRadius: BorderRadius.circular(12),
                    border: Border.all(
                      color: _isShowingMax 
                          ? Colors.blue.shade400 
                          : Colors.green.shade400,
                      width: 2,
                    ),
                  ),
                  child: Center(
                    child: Text(
                      _result,
                      style: TextStyle(
                        fontSize: 24,
                        fontWeight: FontWeight.bold,
                        color: _isShowingMax 
                            ? Colors.blue.shade800 
                            : Colors.green.shade800,
                      ),
                    ),
                  ),
                ),
            ],
          ),
        ),
      ),
    );
  }
}