import 'package:flutter/material.dart';

enum SelectionOption { all, none }

class OrderFoodScreen extends StatefulWidget {
  const OrderFoodScreen({super.key});

  @override
  State<OrderFoodScreen> createState() => _OrderFoodScreenState();
}

class _OrderFoodScreenState extends State<OrderFoodScreen> {
  SelectionOption? _selectionOption;
  bool _isPizzaSelected = false;
  bool _isFrenchFriesSelected = false;
  bool _isColddrinkSelected = false;

  final Map<String, double> _items = {
    'Pizza': 250.0,
    'French Fries': 80.0,
    'Colddrink': 50.0,
  };

  String _getSelectedItemsText() {
    List<String> selectedItems = [];
    if (_isPizzaSelected) selectedItems.add('Pizza');
    if (_isFrenchFriesSelected) selectedItems.add('French Fries');
    if (_isColddrinkSelected) selectedItems.add('Colddrink');
    
    return selectedItems.isEmpty ? 'No items selected' : 'Selected Items: ${selectedItems.join(", ")}';
  }

  double _calculateTotalPrice() {
    double total = 0;
    if (_isPizzaSelected) total += _items['Pizza']!;
    if (_isFrenchFriesSelected) total += _items['French Fries']!;
    if (_isColddrinkSelected) total += _items['Colddrink']!;
    return total;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text('Order Food')),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Row(
              children: [
                Expanded(
                  child: RadioListTile<SelectionOption>(
                    title: const Text('Select All'),
                    value: SelectionOption.all,
                    groupValue: _selectionOption,
                    onChanged: (value) => setState(() {
                      _selectionOption = value;
                      _isPizzaSelected = _isFrenchFriesSelected = _isColddrinkSelected = true;
                    }),
                  ),
                ),
                Expanded(
                  child: RadioListTile<SelectionOption>(
                    title: const Text('Select None'),
                    value: SelectionOption.none,
                    groupValue: _selectionOption,
                    onChanged: (value) => setState(() {
                      _selectionOption = value;
                      _isPizzaSelected = _isFrenchFriesSelected = _isColddrinkSelected = false;
                    }),
                  ),
                ),
              ],
            ),
            
            const Divider(),
            
            CheckboxListTile(
              title: const Text('Pizza (Rs. 250)'),
              value: _isPizzaSelected,
              onChanged: (value) => setState(() {
                _isPizzaSelected = value!;
                _updateRadioSelection();
              }),
              controlAffinity: ListTileControlAffinity.leading,
            ),
            
            CheckboxListTile(
              title: const Text('French Fries (Rs. 80)'),
              value: _isFrenchFriesSelected,
              onChanged: (value) => setState(() {
                _isFrenchFriesSelected = value!;
                _updateRadioSelection();
              }),
              controlAffinity: ListTileControlAffinity.leading,
            ),
            
            CheckboxListTile(
              title: const Text('Colddrink (Rs. 50)'),
              value: _isColddrinkSelected,
              onChanged: (value) => setState(() {
                _isColddrinkSelected = value!;
                _updateRadioSelection();
              }),
              controlAffinity: ListTileControlAffinity.leading,
            ),
            
            const SizedBox(height: 20),
            
            Container(
              padding: const EdgeInsets.all(12),
              decoration: BoxDecoration(
                color: Colors.blue.shade50,
                borderRadius: BorderRadius.circular(8),
                border: Border.all(color: Colors.blue.shade200),
              ),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text(_getSelectedItemsText()),
                  const SizedBox(height: 8),
                  Text(
                    'Total Price: Rs. ${_calculateTotalPrice().toStringAsFixed(2)}',
                    style: const TextStyle(fontWeight: FontWeight.bold),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }

  void _updateRadioSelection() {
    if (_isPizzaSelected && _isFrenchFriesSelected && _isColddrinkSelected) {
      _selectionOption = SelectionOption.all;
    } else if (!_isPizzaSelected && !_isFrenchFriesSelected && !_isColddrinkSelected) {
      _selectionOption = SelectionOption.none;
    } else {
      _selectionOption = null;
    }
  }
}