import 'package:flutter/material.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Image Layout Demo',
      theme: ThemeData(
        colorScheme: ColorScheme.fromSeed(seedColor: Colors.deepPurple),
        useMaterial3: true,
      ),
      home: const TabLayoutPage(),
    );
  }
}

class TabLayoutPage extends StatefulWidget {
  const TabLayoutPage({super.key});

  @override
  State<TabLayoutPage> createState() => _TabLayoutPageState();
}

class _TabLayoutPageState extends State<TabLayoutPage> with SingleTickerProviderStateMixin {
  late TabController _tabController;

  @override
  void initState() {
    super.initState();
    _tabController = TabController(length: 2, vsync: this);
  }

  @override
  void dispose() {
    _tabController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Image Layout Demo'),
        backgroundColor: Theme.of(context).colorScheme.inversePrimary,
        bottom: TabBar(
          controller: _tabController,
          tabs: const [
            Tab(text: 'Row Layout', icon: Icon(Icons.view_week)),
            Tab(text: 'Column Layout', icon: Icon(Icons.view_day)),
          ],
        ),
      ),
      body: TabBarView(
        controller: _tabController,
        children: [
          // First tab with Row layout and light blue background
          Container(
            color: Colors.lightBlue.shade100,
            child: Center(
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  _buildImageContainer('https://picsum.photos/id/237/150/150'),
                  _buildImageContainer('https://picsum.photos/id/238/150/150'),
                  _buildImageContainer('https://picsum.photos/id/239/150/150'),
                ],
              ),
            ),
          ),
          // Second tab with Column layout and light green background
          Container(
            color: Colors.lightGreen.shade100,
            child: Center(
              child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  _buildImageContainer('https://picsum.photos/id/240/150/150'),
                  _buildImageContainer('https://picsum.photos/id/241/150/150'),
                  _buildImageContainer('https://picsum.photos/id/242/150/150'),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }

  Widget _buildImageContainer(String imageUrl) {
    return Container(
      decoration: BoxDecoration(
        border: Border.all(color: Colors.grey),
        borderRadius: BorderRadius.circular(10),
        boxShadow: [
          BoxShadow(
            color: Colors.black.withOpacity(0.2),
            spreadRadius: 1,
            blurRadius: 5,
            offset: const Offset(0, 3),
          ),
        ],
      ),
      child: ClipRRect(
        borderRadius: BorderRadius.circular(10),
        child: Image.network(
          imageUrl,
          width: 150,
          height: 150,
          fit: BoxFit.cover,
          loadingBuilder: (context, child, loadingProgress) {
            if (loadingProgress == null) return child;
            return const Center(child: CircularProgressIndicator());
          },
          errorBuilder: (context, error, stackTrace) {
            return Container(
              width: 150,
              height: 150,
              color: Colors.grey.shade300,
              child: const Icon(Icons.error, color: Colors.red),
            );
          },
        ),
      ),
    );
  }
}
