import 'package:flutter/material.dart';

void main() {
  debugPrint('App is starting...');
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    debugPrint('Building MyApp widget...');
    return MaterialApp(
      title: 'Scrollable List Demo',
      theme: ThemeData(
        colorScheme: ColorScheme.fromSeed(seedColor: Colors.deepPurple),
      ),
      home: const MyHomePage(title: 'Scrollable List Demo'),
    );
  }
}

class MyHomePage extends StatelessWidget {
  const MyHomePage({super.key, required this.title});

  final String title;

  @override
  Widget build(BuildContext context) {
    debugPrint('Building MyHomePage widget...');
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Theme.of(context).colorScheme.inversePrimary,
        title: Text(title),
      ),
      body: DynamicListView(),
    );
  }
}

class DynamicListView extends StatelessWidget {
  DynamicListView({super.key}) {
    debugPrint('Initializing DynamicListView...');
  }

  final List<String> items = List.generate(25, (index) => 'Item ${index + 1}');

  @override
  Widget build(BuildContext context) {
    debugPrint('Building DynamicListView with ${items.length} items...');
    return ListView.builder(
      itemCount: items.length,
      itemBuilder: (context, index) {
        debugPrint('Building item $index: ${items[index]}');
        return ListTile(
          leading: CircleAvatar(
            backgroundColor: Colors.deepPurple[(index % 9 + 1) * 100],
            child: Text('${index + 1}', style: const TextStyle(color: Colors.white)),
          ),
          title: Text(items[index]),
          subtitle: Text('This is the description for ${items[index]}'),
        );
      },
    );
  }
}
