import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'House Lights Control',
      theme: ThemeData(
        primarySwatch: Colors.blue,
        useMaterial3: true,
      ),
      home: const LightsControl(),
    );
  }
}

class LightsControl extends StatefulWidget {
  const LightsControl({super.key});

  @override
  State<LightsControl> createState() => _LightsControlState();
}

class _LightsControlState extends State<LightsControl> {
  final Map<String, bool> lights = {
    'Hall': false,
    'Kitchen': false,
    'Bedroom': false,
    'Lobby': false,
  };

  // Toggle all lights on or off
  void toggleAllLights(bool value) {
    setState(() {
      for (String key in lights.keys) {
        lights[key] = value;
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('House Lights Control'),
      ),
      // Add drawer
      drawer: Drawer(
        child: ListView(
          padding: EdgeInsets.zero,
          children: [
            DrawerHeader(
              decoration: BoxDecoration(
                color: Theme.of(context).primaryColor,
              ),
              child: const Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Text(
                    'House Lights',
                    style: TextStyle(
                      color: Colors.white,
                      fontSize: 24,
                    ),
                  ),
                  SizedBox(height: 8),
                  Text(
                    'Control Panel',
                    style: TextStyle(
                      color: Colors.white,
                      fontSize: 16,
                    ),
                  ),
                ],
              ),
            ),
            // Light On-OFF option
            ListTile(
              leading: const Icon(Icons.lightbulb),
              title: const Text('Light On-OFF'),
              onTap: () {
                // Close drawer
                Navigator.pop(context);
                
                // Show dialog to toggle all lights
                showDialog(
                  context: context,
                  builder: (BuildContext context) {
                    return AlertDialog(
                      title: const Text('Light Controls'),
                      content: const Text('Turn all lights on or off?'),
                      actions: [
                        TextButton(
                          onPressed: () {
                            toggleAllLights(true);
                            Navigator.pop(context);
                          },
                          child: const Text('ALL ON'),
                        ),
                        TextButton(
                          onPressed: () {
                            toggleAllLights(false);
                            Navigator.pop(context);
                          },
                          child: const Text('ALL OFF'),
                        ),
                        TextButton(
                          onPressed: () {
                            Navigator.pop(context);
                          },
                          child: const Text('CANCEL'),
                        ),
                      ],
                    );
                  },
                );
              },
            ),
            // Exit option
            ListTile(
              leading: const Icon(Icons.exit_to_app),
              title: const Text('Exit'),
              onTap: () {
                // Exit the app
                SystemNavigator.pop();
              },
            ),
          ],
        ),
      ),
      body: SafeArea(
        child: Padding(
          padding: const EdgeInsets.all(8.0),
          child: Column(
            children: [
              // Bulbs section - reduced size
              SizedBox(
                height: 220,
                child: GridView.builder(
                  physics: const NeverScrollableScrollPhysics(),
                  padding: const EdgeInsets.symmetric(vertical: 8),
                  gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
                    crossAxisCount: 2,
                    childAspectRatio: 1.2,
                    mainAxisSpacing: 8,
                    crossAxisSpacing: 8,
                  ),
                  itemCount: 4,
                  itemBuilder: (context, index) {
                    String roomName = lights.keys.elementAt(index);
                    bool isOn = lights[roomName]!;
                    return Card(
                      elevation: 2,
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.center,
                        children: [
                          Icon(
                            Icons.lightbulb,
                            size: 40,
                            color: isOn ? Colors.yellow : Colors.grey,
                          ),
                          const SizedBox(height: 4),
                          Text(roomName),
                        ],
                      ),
                    );
                  },
                ),
              ),
              
              // Divider
              const Divider(thickness: 1),
              
              // Checkboxes section - more compact
              ListView.builder(
                physics: const NeverScrollableScrollPhysics(),
                shrinkWrap: true,
                itemCount: lights.length,
                itemBuilder: (context, index) {
                  String room = lights.keys.elementAt(index);
                  return CheckboxListTile(
                    dense: true,
                    title: Text(room),
                    value: lights[room],
                    onChanged: (value) {
                      setState(() {
                        lights[room] = value!;
                      });
                    },
                  );
                },
              ),
            ],
          ),
        ),
      ),
    );
  }
}
